<p align="center">
    <a href="https://pypi.org/project/alchemica" target="_blank">
        <img src="https://img.shields.io/pypi/v/alchemica" alt="PyPI">
    </a>
    <a href="https://pypi.org/project/alchemica" target="_blank">
        <img src="https://static.pepy.tech/badge/alchemica" alt="PyPI">
    </a>
    <a href="https://opensource.org/licenses/Apache-2.0" target="_blank">
        <img src="https://img.shields.io/badge/License-Apache_2.0-blue.svg" alt="Apache">
    </a>
</p>

<p align="center">
      <a href="https://github.com/gri-gus/alchemica" target="_blank">
        <img src="https://img.shields.io/badge/github-%23121011.svg?style=for-the-badge&logo=github&logoColor=white" alt="GitHub">
    </a>
</p>

# alchemica - SQLAlchemy Logger

`alchemica` is a library for logging SQL queries in applications using SQLAlchemy. It allows you to track the execution of
SQL queries, their execution time, display the query plan, and also output warnings if queries take too long.
The project provides decorators that are easy to integrate into the code and allow you to effectively log SQL queries.

